@@ -1,5 +1,5 @@
 /* AbiSource Program Utilities
- * Copyright (C) 1998 AbiSource, Inc.
+ * Copyright (C) 2001 AbiSource, Inc.
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@ public:
 	UT_uint32 	getIndxFromEncoding(const XML_Char * enc);
 	UT_uint32 	getIdFromEncoding(const XML_Char * enc);
 
-protected:
+private:
 	static bool	s_Init;
 	static UT_uint32	s_iCount;
 };
