@@ -343,6 +343,24 @@ GR_Font* FL_DocLayout::findFont(const PP_AttrProp * pSpanAP,
 	return pFont;
 }
 
+void FL_DocLayout::changeDocSections(const PX_ChangeRecord_StruxChange * pcrx, fl_DocSectionLayout * pDSL)
+{
+	fl_DocSectionLayout * pCur = pDSL;
+	pDSL->doclistener_changeStrux(pcrx);
+	while(pCur != NULL)
+	{
+		pCur->collapseDocSection();
+		pCur = pCur->getNextDocSection();
+	}
+	pCur = pDSL;
+	while(pCur != NULL)
+	{
+		pCur->updateDocSection();
+		pCur = pCur->getNextDocSection();
+	}
+}
+
+
 UT_uint32 FL_DocLayout::countPages()
 {
 	return m_vecPages.getItemCount();
@@ -375,7 +393,7 @@ fp_Page* FL_DocLayout::getLastPage()
 	return (fp_Page*) m_vecPages.getNthItem(m_vecPages.getItemCount()-1);
 }
 
-void FL_DocLayout::deletePage(fp_Page* pPage)
+void FL_DocLayout::deletePage(fp_Page* pPage, bool bDontNotify /* default false */)
 {
 	UT_sint32 ndx = m_vecPages.findItem(pPage);
 	UT_ASSERT(ndx >= 0);
@@ -389,7 +407,7 @@ void FL_DocLayout::deletePage(fp_Page* pPage)
 	{
 		pPage->getNext()->setPrev(pPage->getPrev());
 	}
-		
+
 	m_vecPages.deleteNthItem(ndx);
 	delete pPage;
 		
@@ -397,7 +415,7 @@ void FL_DocLayout::deletePage(fp_Page* pPage)
 	// so that it can update the scroll bar ranges
 	// and whatever else it needs to do.
 
-	if (m_pView)
+	if (m_pView && !bDontNotify)
 	{
 		m_pView->notifyListeners(AV_CHG_PAGECOUNT);
 	}
@@ -537,7 +555,7 @@ void FL_DocLayout::deleteEmptyColumnsAndPages(void)
 	deleteEmptyPages();
 }
 
-void FL_DocLayout::deleteEmptyPages(void)
+void FL_DocLayout::deleteEmptyPages( bool bDontNotify /* default false */)
 {
 	int i;
 
@@ -548,7 +566,7 @@ void FL_DocLayout::deleteEmptyPages(void)
 
 		if (p->isEmpty())
 		{
-			deletePage(p);
+			deletePage(p, bDontNotify);
 		}
 	}
 }
@@ -1293,7 +1311,14 @@ void FL_DocLayout::_redrawUpdate(UT_Timer * pTimer)
 //
 	PD_Document * pDoc = pDocLayout->getDocument();
 	if(pDoc->isPieceTableChanging())
+	{  
+		UT_DEBUGMSG(("PieceTable changing don't redraw \n"));
 		return;
+	}
+//
+// Lock out PieceTable changes till we finished.
+//
+	pDoc->setRedrawHappenning(true);
 //
 // Check if we've been asked to wait for a while..
 //
@@ -1302,6 +1327,7 @@ void FL_DocLayout::_redrawUpdate(UT_Timer * pTimer)
 	{
 		skip--;
 		pDocLayout->setSkipUpdates(skip);
+		pDoc->setRedrawHappenning(false);
 		return;
 	}
 //
@@ -1309,6 +1335,7 @@ void FL_DocLayout::_redrawUpdate(UT_Timer * pTimer)
 //
 	if(pDocLayout->m_pG->queryProperties(GR_Graphics::DGP_PAPER))
 	{
+		pDoc->setRedrawHappenning(false);
 		return;
 	}
 
@@ -1316,41 +1343,19 @@ void FL_DocLayout::_redrawUpdate(UT_Timer * pTimer)
 	while (pSL)
 	{
 		if(pDoc->isPieceTableChanging())
+		{
+			pDoc->setRedrawHappenning(false);
 			return;
+		}
 		pSL->redrawUpdate();
 		pSL = pSL->getNext();
 	}
 
 	pDocLayout->deleteEmptyColumnsAndPages();
-	
-
-/*
-  UT_Vector* vecToCheck = &pDocLayout->m_vecUncheckedBlocks;
-  UT_ASSERT(vecToCheck);
-
-  UT_uint32 i = vecToCheck->getItemCount();
-
-  if (i > 0)
-  {
-  fl_BlockLayout *pB = (fl_BlockLayout *) vecToCheck->getFirstItem();
-
-  if (pB != NULL)
-  {
-  vecToCheck->deleteNthItem(0);
-  i--;
-
-  //	note that we remove this block from queue before checking it
-  //	(otherwise asserts could trigger redundant recursive calls)
-  pB->checkSpelling();
-  }
-  }
-
-  if (i == 0)
-  {
-  // timer not needed any more, so suspend it
-  pDocLayout->m_pSpellCheckTimer->stop();
-  }
-*/
+//
+// we've finished
+//
+	pDoc->setRedrawHappenning(false);
 }
 
 void FL_DocLayout::setPendingSmartQuote(fl_BlockLayout *bl, UT_uint32 of)
