@@ -188,7 +188,6 @@ fl_BlockLayout * fl_SectionLayout::insertBlock(PL_StruxDocHandle sdh, fl_BlockLa
 	{
 		m_pFirstBlock = pBL;
 	}
-
 	return pBL;
 }
 
@@ -413,6 +412,7 @@ fl_DocSectionLayout::fl_DocSectionLayout(FL_DocLayout* pLayout, PL_StruxDocHandl
 	m_pEndnoteSL = NULL;
 	m_pEndnoteOwnerSL = NULL;
 	m_pFirstOwnedPage = NULL;
+	m_bNeedsFormat = false;
 	_lookupProperties();
 }
 
@@ -532,7 +532,7 @@ fp_Container* fl_DocSectionLayout::getNewContainer(void)
 	fp_Page* pPage = NULL;
 	fp_Column* pLastColumn = (fp_Column*) getLastContainer();
 	fp_Column* pAfterColumn = NULL;
-	
+
 	if (pLastColumn)
 	{
 		fp_Page* pTmpPage = pLastColumn->getPage();
@@ -555,6 +555,10 @@ fp_Container* fl_DocSectionLayout::getNewContainer(void)
 		fl_DocSectionLayout* pPrevSL = getPrevDocSection();
 		if (pPrevSL)
 		{
+//
+// This should make sure the last column in the previous section  has it's last container
+// on a sane page.
+//
 			//
 			// Sevior this code should not be needed!
 			//
@@ -565,7 +569,24 @@ fp_Container* fl_DocSectionLayout::getNewContainer(void)
 				pPrevSL->format();
 			}
 			fp_Page* pTmpPage = pPrevSL->getLastContainer()->getPage();
-			if (m_bForceNewPage)
+			UT_sint32 iMaxColHeight = pPrevCol->getMaxHeightInLayoutUnits();
+			UT_sint32 iCurColHeight =  0;
+			fp_Column * pLeader = pPrevCol->getLeader();
+			fp_Column *pMaxCol = NULL;
+			while(pLeader != NULL)
+			{
+				if( pLeader->getHeightInLayoutUnits() > iCurColHeight)
+				{
+					pMaxCol = pLeader;
+					iCurColHeight =  pLeader->getHeightInLayoutUnits();
+				}
+				pLeader = pLeader->getFollower();
+			}
+			UT_sint32 iLastLineHeight = 0;
+			if(pMaxCol->getLastLine() != NULL)
+				iLastLineHeight = pMaxCol->getLastLine()->getHeightInLayoutUnits();
+			bool bForce = (iCurColHeight + iLastLineHeight) >= iMaxColHeight;
+			if (m_bForceNewPage || bForce)
 			{
 				if (pTmpPage->getNext())
 				{
@@ -604,10 +625,10 @@ fp_Container* fl_DocSectionLayout::getNewContainer(void)
 	// Create row of columns
 	fp_Column* pLeaderColumn = NULL;
 	fp_Column* pTail = NULL;
-	for (UT_uint32 i=0; i<m_iNumColumns; i++)
+	UT_uint32 i = 0;
+	for (i=0; i<m_iNumColumns; i++)
 	{
 		fp_Column* pCol = new fp_Column(this);
-
 		if (pTail)
 		{
 			pCol->setLeader(pLeaderColumn);
@@ -647,15 +668,18 @@ fp_Container* fl_DocSectionLayout::getNewContainer(void)
 	}
 	m_pLastColumn = pLastNewCol;
 	UT_ASSERT(!(m_pLastColumn->getNext()));
+	UT_ASSERT(!(m_pLastColumn->getFollower()));
 
 	pPage->insertColumnLeader(pLeaderColumn, pAfterColumn);
 	
 	fp_Column* pTmpCol = pLeaderColumn;
+	i = 0;
  	while (pTmpCol)
 	{
 		UT_ASSERT(pTmpCol->getPage());
 		
 		pTmpCol = pTmpCol->getFollower();
+		i++;
 	}
 
 	return pLeaderColumn;
@@ -683,6 +707,7 @@ void fl_DocSectionLayout::format(void)
 	}
 
 	breakSection();
+	m_bNeedsFormat = false;
 }
 
 void fl_DocSectionLayout::updateLayout(void)
@@ -721,79 +746,27 @@ bool fl_DocSectionLayout::doclistener_changeStrux(const PX_ChangeRecord_StruxCha
 {
 	UT_ASSERT(pcrxc->getType()==PX_ChangeRecord::PXT_ChangeStrux);
 
-	PT_AttrPropIndex indexAP = pcrxc->getIndexAP();
-	const PP_AttrProp* pAP = NULL;
-			
-	bool bres = (m_pDoc->getAttrProp(indexAP, &pAP) && pAP);
-	UT_ASSERT(bres);
-	
-	const XML_Char* pszSectionType = NULL;
-	pAP->getAttribute("type", pszSectionType);
 
 	setAttrPropIndex(pcrxc->getIndexAP());
+	return true;
+}
+
+void fl_DocSectionLayout::updateDocSection(void)
+{
+
+	const PP_AttrProp* pAP = NULL;
+	bool bres = m_pDoc->getAttrProp(m_apIndex, &pAP);
+	UT_ASSERT(bres);
+	
+
+	const XML_Char* pszSectionType = NULL;
+	pAP->getAttribute("type", pszSectionType);
 
 	_lookupProperties();
 
 	// clear all the columns
-	fp_Column* pCol = m_pFirstColumn;
-	while (pCol)
-	{
-		pCol->clearScreen();
-
-		pCol = pCol->getNext();
-	}
-	//
-	// Clear the header/footers too
-	//
-	if(m_pHeaderSL)
-		m_pHeaderSL->clearScreen();
-	if(m_pFooterSL)
-		m_pFooterSL->clearScreen();
-	//
-	// Collapse the header/footers now
-	//
-  	if(m_pHeaderSL)
-		m_pHeaderSL->collapse();
-  	if(m_pFooterSL)
-		m_pFooterSL->collapse();
-
-	// remove all the columns from their pages
-	pCol = m_pFirstColumn;
-	while (pCol)
-	{
-		if (pCol->getLeader() == pCol)
-		{
-			pCol->getPage()->removeColumnLeader(pCol);
-		}
-
-		pCol = pCol->getNext();
-	}
-
-
-	m_pFirstColumn = NULL;
-	m_pLastColumn = NULL;
-
-	// get rid of all the layout information for every block
-	fl_BlockLayout*	pBL = m_pFirstBlock;
-	while (pBL)
-	{
-		pBL->collapse();
-
-		pBL = pBL->getNext();
-	}
-
-	// delete all our columns
-	pCol = m_pFirstColumn;
-	while (pCol)
-	{
-		fp_Column* pNext = pCol->getNext();
-
-		delete pCol;
-
-		pCol = pNext;
-	}
-	m_pFirstColumn = NULL;
-	m_pLastColumn = NULL;
+    // Assume that all columns and formatting have already been removed via a collapseDocSection()
+    //
 
 	/*
 	  TODO to more closely mirror the architecture we're using for BlockLayout, this code
@@ -824,11 +797,12 @@ bool fl_DocSectionLayout::doclistener_changeStrux(const PX_ChangeRecord_StruxCha
 	FV_View* pView = m_pLayout->getView();
 	if (pView)
 	{
+		pView->eraseInsertionPoint();
 		pView->updateScreen(false);
 		pView->notifyListeners(AV_CHG_TYPING | AV_CHG_FMTSECTION);
 	}
 
-	return false;
+	return;
 }
 
 void fl_DocSectionLayout::_lookupProperties(void)
@@ -1184,20 +1158,8 @@ fl_DocSectionLayout* fl_DocSectionLayout::getPrevDocSection(void) const
 	return pSL;
 }
 
-bool fl_DocSectionLayout::doclistener_deleteStrux(const PX_ChangeRecord_Strux * pcrx)
+void fl_DocSectionLayout::collapseDocSection(void)
 {
-	UT_ASSERT(pcrx->getType()==PX_ChangeRecord::PXT_DeleteStrux);
-	UT_ASSERT(pcrx->getStruxType()==PTX_Section);
-
-	fl_DocSectionLayout* pPrevSL = getPrevDocSection();
-	if (!pPrevSL)
-	{
-		// TODO shouldn't this just assert?
-		UT_DEBUGMSG(("no prior SectionLayout"));
-		return false;
-	}
-	
-	// clear all the columns
 	fp_Column* pCol = m_pFirstColumn;
 	while (pCol)
 	{
@@ -1205,6 +1167,20 @@ bool fl_DocSectionLayout::doclistener_deleteStrux(const PX_ChangeRecord_Strux *
 
 		pCol = pCol->getNext();
 	}
+	//
+	// Clear the header/footers too
+	//
+	if(m_pHeaderSL)
+		m_pHeaderSL->clearScreen();
+	if(m_pFooterSL)
+		m_pFooterSL->clearScreen();
+	//
+	// Collapse the header/footers now
+	//
+  	if(m_pHeaderSL)
+		m_pHeaderSL->collapse();
+  	if(m_pFooterSL)
+		m_pFooterSL->collapse();
 
 	// remove all the columns from their pages
 	pCol = m_pFirstColumn;
@@ -1223,7 +1199,6 @@ bool fl_DocSectionLayout::doclistener_deleteStrux(const PX_ChangeRecord_Strux *
 	while (pBL)
 	{
 		pBL->collapse();
-
 		pBL = pBL->getNext();
 	}
 
@@ -1232,40 +1207,82 @@ bool fl_DocSectionLayout::doclistener_deleteStrux(const PX_ChangeRecord_Strux *
 	while (pCol)
 	{
 		fp_Column* pNext = pCol->getNext();
-
 		delete pCol;
-
 		pCol = pNext;
 	}
-
 	m_pFirstColumn = NULL;
 	m_pLastColumn = NULL;
 
-	while (m_pFirstBlock)
+//
+// Remove all the empty pages thus created. Don't notify of the deletion though.
+//
+	getDocLayout()->deleteEmptyPages(true);
+//
+// This Doc Section No longer owns pages so this becomes NULL
+//
+	m_pFirstOwnedPage = NULL;
+}
+
+bool fl_DocSectionLayout::doclistener_deleteStrux(const PX_ChangeRecord_Strux * pcrx)
+{
+	UT_ASSERT(pcrx->getType()==PX_ChangeRecord::PXT_DeleteStrux);
+	UT_ASSERT(pcrx->getStruxType()==PTX_Section);
+
+	fl_DocSectionLayout* pPrevSL = getPrevDocSection();
+	if (!pPrevSL)
 	{
-		pBL = m_pFirstBlock;
-		removeBlock(pBL);
-		pPrevSL->addBlock(pBL);
-	}
-	
-	pPrevSL->m_pNext = m_pNext;
-							
-	if (m_pNext)
-	{
-		m_pNext->setPrev(pPrevSL);
+		// TODO shouldn't this just assert?
+		UT_DEBUGMSG(("no prior SectionLayout"));
+		return false;
 	}
 
+//
+// Collapse previous section too. We need this so it can be rebuilt properly.
+//
+	pPrevSL->collapseDocSection();
+
+	// clear all the columns
+	collapseDocSection();
+
 	if(m_pHeaderSL)
 	{
 		DELETEP(m_pHeaderSL);
+		m_pHeaderSL = NULL;
 	}
 	if(m_pFooterSL)
 	{
 		DELETEP(m_pFooterSL);
+		m_pFooterSL = NULL;
 	}
 
+//
+// Collapse the subsequent sections too. These will be reformatted in a few lines.
+//
+	fl_DocSectionLayout * pDSL = getNextDocSection();
+	while(pDSL != NULL)
+	{
+		pDSL->collapseDocSection();
+		pDSL = pDSL->getNextDocSection();
+	}
+//
+// OK set the links and move all blocks in this section into the previous section.
+//
+	fl_BlockLayout * pBCur = getFirstBlock();
+	fl_BlockLayout * pBPrev = pPrevSL->getLastBlock();
+	pBCur->setPrev(pBPrev);
+	pBPrev->setNext(pBCur);
+	while(pBCur != NULL)
+	{
+		pBCur->setSectionLayout(pPrevSL);
+		pBCur = pBCur->getNext();
+	}
+	m_pFirstBlock = NULL;
+	m_pLastBlock = NULL;
+//
+// Get this before we remove this section from the run list!
+//
+    pDSL = getNextDocSection();
 	m_pLayout->removeSection(this);
-
 	pPrevSL->format();
 	
 //	FV_View* pView = m_pLayout->getView();
@@ -1273,7 +1290,14 @@ bool fl_DocSectionLayout::doclistener_deleteStrux(const PX_ChangeRecord_Strux *
 //  	{
 //  		pView->_setPoint(pcrx->getPosition());
 //  	}
-
+//
+// Update the following sections.
+//
+	while(pDSL != NULL)
+	{
+		pDSL->updateDocSection();
+		pDSL = pDSL->getNextDocSection();
+	}
 	delete this;			// TODO whoa!  this construct is VERY dangerous.
 	
 	return true;
@@ -1333,13 +1357,30 @@ void fl_DocSectionLayout::deleteOwnedPage(fp_Page* pPage)
 	
 	if (m_pHeaderSL)
 	{
+		UT_DEBUGMSG(("SEVIOR: Deleting header from DocSecition Layout\n"));
 		m_pHeaderSL->deletePage(pPage);
 	}
 
 	if (m_pFooterSL)
 	{
+		UT_DEBUGMSG(("SEVIOR: Deleting footer from DocSection Layout \n"));
 		m_pFooterSL->deletePage(pPage);
 	}
+//
+// Remove this page from the list of owned pages
+//
+	if(m_pFirstOwnedPage == pPage)
+	{
+		fp_Page * pNext = pPage->getNext();
+		if(pNext && pNext->getOwningSection() == this)
+		{
+			m_pFirstOwnedPage = pNext;
+		}
+		else
+		{
+			m_pFirstOwnedPage = NULL;
+		}
+	}
 }
 
 /*!
@@ -1389,7 +1430,8 @@ UT_sint32 fl_DocSectionLayout::breakSection(void)
 				continue;
 			}
 		}
-
+		bool bBreakOnColumnBreak = false;
+		bool bBreakOnPageBreak = false;
 		while (pCurLine)
 		{
 			UT_sint32 iLineHeight = pCurLine->getHeightInLayoutUnits();
@@ -1547,13 +1589,17 @@ UT_sint32 fl_DocSectionLayout::breakSection(void)
 					)
 				{
 					pLastLineToKeep = pCurLine;
+					bBreakOnColumnBreak = pCurLine->containsForcedColumnBreak();
+					bBreakOnPageBreak = pCurLine->containsForcedPageBreak();
 					break;
 				}
 			}
 
 			pCurLine = pCurLine->getNextLineInSection();
-		}
-
+		} 
+//
+// End of big while loop here. After this we've found LastLineToKeep
+//
 		if (pLastLineToKeep)
 		{
 			pCurrentLine = pLastLineToKeep->getNextLineInSection();
@@ -1562,7 +1608,9 @@ UT_sint32 fl_DocSectionLayout::breakSection(void)
 		{
 			pCurrentLine = NULL;
 		}
-		
+//
+// OK fill our column with content between pFirstLineToKeep and pLastLineToKeep
+//		
 		pCurLine = pFirstLineToKeep;
 		while (pCurLine)
 		{
@@ -1664,6 +1712,15 @@ fl_HdrFtrSectionLayout::fl_HdrFtrSectionLayout(HdrFtrType iHFType, FL_DocLayout*
 	m_iType = FL_SECTION_HDRFTR;
 	m_pHdrFtrContainer = NULL;
 	fl_Layout::setType(PTX_SectionHdrFtr); // Set the type of this strux
+//
+// Since we're almost certainly removing blocks at the end of the doc, tell the
+// view to remember the current position on the active view.
+//
+	FV_View * pView = m_pLayout->getView();
+	if(pView && pView->isActive())
+	{
+		pView->markSavedPositionAsNeeded();
+	}
 }
 
 fl_HdrFtrSectionLayout::~fl_HdrFtrSectionLayout()
@@ -1740,6 +1797,29 @@ void fl_HdrFtrSectionLayout::collapse(void)
 	DELETEP(m_pHdrFtrContainer);
 }
 
+/*!
+ * This method removes the block pBlock from all the shadowLayouts.
+ */
+void fl_HdrFtrSectionLayout::collapseBlock(fl_BlockLayout *pBlock)
+{
+	UT_uint32 iCount = m_vecPages.getItemCount();
+	UT_uint32 i;
+	for (i=0; i<iCount; i++)
+	{
+		struct _PageHdrFtrShadowPair* pPair = (struct _PageHdrFtrShadowPair*) m_vecPages.getNthItem(i);
+		fl_BlockLayout * pShadowBL = pPair->pShadow->findMatchingBlock(pBlock);
+		UT_ASSERT(pShadowBL);
+		if(pShadowBL)
+		{
+			pPair->pShadow->removeBlock( pShadowBL);
+			// In case we've never checked this one
+			m_pLayout->dequeueBlockForBackgroundCheck(pShadowBL);
+			delete pShadowBL;
+			pPair->pShadow->format();
+		}
+	}
+}
+
 bool fl_HdrFtrSectionLayout::recalculateFields(void)
 {
 	bool bResult = false;
@@ -1940,7 +2020,12 @@ bool fl_HdrFtrSectionLayout::doclistener_deleteStrux(const PX_ChangeRecord_Strux
 
 void fl_HdrFtrSectionLayout::addPage(fp_Page* pPage)
 {
-	UT_ASSERT(0 > _findShadow(pPage));
+//
+//  Sevior:
+//  This triggers if we're rebuilding a section before page is defined like in a section change
+//  strux. Reinstate if needed to find other bugs.
+//	UT_ASSERT(0 > _findShadow(pPage));
+
 	UT_sint32 icnt = m_vecPages.getItemCount();
 	if(_findShadow(pPage) > -1)
 		return;
@@ -1992,7 +2077,7 @@ void fl_HdrFtrSectionLayout::deletePage(fp_Page* pPage)
 //
 // This shadow might have already been deleted via the collapse method
 //
-	if(iShadow <= 0)
+	if(iShadow <  0)
 		return;
 	struct _PageHdrFtrShadowPair* pPair = (struct _PageHdrFtrShadowPair*) m_vecPages.getNthItem(iShadow);
 	UT_ASSERT(pPair);
@@ -2004,10 +2089,12 @@ void fl_HdrFtrSectionLayout::deletePage(fp_Page* pPage)
 	delete pPair->pShadow;
 	if (getHFType() == FL_HDRFTR_HEADER)
 	{
+		UT_DEBUGMSG(("SEVIOR: Remove header from shadow \n"));
 		ppPage->removeHeader();
 	}
 	else 
 	{
+		UT_DEBUGMSG(("SEVIOR: Remove footer form shadow \n"));
 		ppPage->removeFooter();
 	}
 
@@ -2309,7 +2396,6 @@ bool fl_HdrFtrSectionLayout::bl_doclistener_insertSpan(fl_BlockLayout* pBL, cons
 		// Find matching block in this shadow.
 
 		pShadowBL = pPair->pShadow->findMatchingBlock(pBL);
-		xxx_UT_DEBUGMSG(("SEVIOR: SectionLayout for shadow %d is %x \n",i,pShadowBL->getSectionLayout()));
 		bResult = pShadowBL->doclistener_insertSpan(pcrs)
 			&& bResult;
 	}
@@ -2420,12 +2506,7 @@ bool fl_HdrFtrSectionLayout::bl_doclistener_changeStrux(fl_BlockLayout* pBL, con
 	return bResult;
 }
 
-bool fl_HdrFtrSectionLayout::bl_doclistener_insertBlock(fl_BlockLayout* pBL, const PX_ChangeRecord_Strux * pcrx,
-														PL_StruxDocHandle sdh,
-														PL_ListenerId lid,
-														void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
-																				PL_ListenerId lid,
-																				PL_StruxFmtHandle sfhNew))
+bool fl_HdrFtrSectionLayout::bl_doclistener_insertBlock(fl_BlockLayout* pBL, const PX_ChangeRecord_Strux * pcrx,PL_StruxDocHandle sdh,PL_ListenerId lid,void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,	PL_ListenerId lid, PL_StruxFmtHandle sfhNew))
 {
 	bool bResult = true;
 //
@@ -2439,31 +2520,59 @@ bool fl_HdrFtrSectionLayout::bl_doclistener_insertBlock(fl_BlockLayout* pBL, con
 		struct _PageHdrFtrShadowPair* pPair = (struct _PageHdrFtrShadowPair*) m_vecPages.getNthItem(i);
 
 		// Find matching block in this shadow.
-
-		pShadowBL = pPair->pShadow->findMatchingBlock(pBL);
-		bResult = pShadowBL->doclistener_insertBlock(pcrx,sdh,lid,pfnBindHandles)
-			&& bResult;
+		if(pBL)
+		{
+			pShadowBL = pPair->pShadow->findMatchingBlock(pBL);
+			bResult = pShadowBL->doclistener_insertBlock(pcrx,sdh,lid,pfnBindHandles)
+				&& bResult;
+		}
+		else
+//
+// This is the first block in the shadow
+//
+		{
+			fl_BlockLayout*	pNewBL = pPair->pShadow->insertBlock(sdh, NULL, pcrx->getIndexAP());
+			if (!pNewBL)
+			{
+				UT_DEBUGMSG(("no memory for BlockLayout\n"));
+				return false;
+			}
+			bResult = bResult && pNewBL->doclistener_insertFirstBlock(pcrx, sdh, 
+													lid, pfnBindHandles);
+		}
 	}
 //
 // Find Matching Block in this HdrFtrSectionLayout!!
 //
-	fl_BlockLayout * ppBL = findMatchingBlock(pBL);
+	if(pBL)
+	{
+		fl_BlockLayout * ppBL = findMatchingBlock(pBL);
+		m_pDoc->allowChangeInsPoint();
 
-//	localFormat();
-	m_pDoc->allowChangeInsPoint();
-
-	xxx_UT_DEBUGMSG(("In hdrFtr Block %x marked as hdrftr state %d \n",ppBL,ppBL->isHdrFtr()));
-    ppBL->setHdrFtr();
-    bResult = ppBL->doclistener_insertBlock(pcrx,sdh,lid,pfnBindHandles)
-		&& bResult;
+		ppBL->setHdrFtr();
+		bResult = ppBL->doclistener_insertBlock(pcrx,sdh,lid,pfnBindHandles)
+			&& bResult;
 //
 // Mark the Block as HdrFtr
 //
-	ppBL->getNext()->setHdrFtr();
-	xxx_UT_DEBUGMSG(("Marking Block %x as Header/Footer \n",ppBL->getNext()));
-//	format();
-//	updateLayout();
-//	redrawUpdate();
+		ppBL->getNext()->setHdrFtr();
+	}
+	else
+//
+// First block in the section
+//
+	{
+		fl_BlockLayout*	pNewBL = insertBlock(sdh, NULL, pcrx->getIndexAP());
+		if (!pNewBL)
+		{
+			UT_DEBUGMSG(("no memory for BlockLayout\n"));
+			return false;
+		}
+		bResult = bResult && pNewBL->doclistener_insertFirstBlock(pcrx, sdh, 
+													lid, pfnBindHandles);
+		m_pDoc->allowChangeInsPoint();
+		pNewBL->setHdrFtr();
+	}
 	return bResult;
 }
 
