@@ -59,7 +59,7 @@ fp_Page::fp_Page(FL_DocLayout* pLayout,
 	UT_ASSERT(pG);
 
 	m_iResolution = pG->getResolution();
-
+	UT_ASSERT(m_pOwner);
 	m_pOwner->addOwnedPage(this);
 }
 
@@ -109,6 +109,7 @@ UT_sint32 fp_Page::getBottom(void) const
 	fp_Column* pFirstColumnLeader = getNthColumnLeader(0);
 	fl_DocSectionLayout* pFirstSectionLayout = pFirstColumnLeader->getDocSectionLayout();
 	UT_ASSERT(m_pOwner == pFirstSectionLayout);
+
 //	UT_sint32 iTopMargin = pFirstSectionLayout->getTopMargin();
 	UT_sint32 iBottomMargin = pFirstSectionLayout->getBottomMargin();
 	
@@ -154,10 +155,13 @@ void fp_Page::_drawCropMarks(dg_DrawArgs* pDA)
 {
     if(m_pView->getShowPara() 
 	   && pDA->pG->queryProperties(GR_Graphics::DGP_SCREEN)
-	   && countColumnLeaders() > 0){
+	   && countColumnLeaders() > 0)
+	{
         fp_Column* pFirstColumnLeader = getNthColumnLeader(0);
         fl_DocSectionLayout* pFirstSectionLayout = (pFirstColumnLeader->getDocSectionLayout());
-        UT_ASSERT(m_pOwner == pFirstSectionLayout);
+		UT_ASSERT(m_pOwner == pFirstSectionLayout);
+
+
         UT_sint32 iLeftMargin = pFirstSectionLayout->getLeftMargin();
         UT_sint32 iRightMargin = pFirstSectionLayout->getRightMargin();
         UT_sint32 iTopMargin = pFirstSectionLayout->getTopMargin();
@@ -201,7 +205,7 @@ void fp_Page::draw(dg_DrawArgs* pDA, bool bAlwaysUseWhiteBackground)
 //
 	if(!bAlwaysUseWhiteBackground && !pDA->pG->queryProperties(GR_Graphics::DGP_SCREEN))
 	{
-		UT_DEBUGMSG(("SEVIOR: Doing a rectangular color fill \n"));
+		xxx_UT_DEBUGMSG(("Doing a rectangular color fill \n"));
 		UT_RGBColor * pClr = getOwningSection()->getPaperColor();
 		double ScaleLayoutUnitsToScreen;
 		ScaleLayoutUnitsToScreen = (double)pDA->pG->getResolution() / UT_LAYOUT_UNITS;
@@ -287,7 +291,9 @@ void fp_Page::_reformat(void)
 
 	fp_Column* pFirstColumnLeader = getNthColumnLeader(0);
 	fl_DocSectionLayout* pFirstSectionLayout = (pFirstColumnLeader->getDocSectionLayout());
+	
 	UT_ASSERT(m_pOwner == pFirstSectionLayout);
+	
 	UT_sint32 iLeftMargin = pFirstSectionLayout->getLeftMargin();
 	UT_sint32 iRightMargin = pFirstSectionLayout->getRightMargin();
 	UT_sint32 iTopMargin = pFirstSectionLayout->getTopMargin();
@@ -338,10 +344,8 @@ void fp_Page::_reformat(void)
 			pTmpCol->setWidth(iColWidth);
 			pTmpCol->setWidthInLayoutUnits(iColWidthLayoutUnits);
 			iX += (iColWidth + iColumnGap);
-
 			iMostHeight = UT_MAX(iMostHeight, pTmpCol->getHeight());
 			iMostHeightLayoutUnits = UT_MAX(iMostHeightLayoutUnits, pTmpCol->getHeightInLayoutUnits());
-
 			pTmpCol = pTmpCol->getFollower();
 		}
 
@@ -352,15 +356,101 @@ void fp_Page::_reformat(void)
 		iYLayoutUnits += pLeader->getDocSectionLayout()->getSpaceAfterInLayoutUnits();
 	}
 
-	while (i < count)
+//
+// We enter this loop if there are column Leaders left but no space to put them
+// on the page. These will have to be deleted and the content restributed on 
+// subsequent pages.
+//
+// OK collapse the blocks with lines in this container. Then format the section.
+//
+	if(i<count)
 	{
-		// fp_Column* pLeader = getNthColumnLeader(i);
-		// fl_DocSectionLayout* pSL = pLeader->getDocSectionLayout();
+		fl_DocSectionLayout * pCurSL = NULL;
+		UT_uint32 numValidLeaders = (UT_uint32) i;
+		while (i < count)
+		{
+			fp_Column* pLeader = getNthColumnLeader(i);
+			fl_DocSectionLayout* pSL = pLeader->getDocSectionLayout();
+			fl_BlockLayout *pCurBL = NULL;
+			while(pLeader != NULL)
+			{
+				UT_Vector vBlock;
+				vBlock.clear();
+				fp_Line * pLine = pLeader->getFirstLine();
+				while(pLine != NULL)
+				{
+					if(pLine->getBlock() != pCurBL)
+					{
+						pCurBL = pLine->getBlock();
+						if(vBlock.getItemCount() == 0)
+						{
+							vBlock.addItem( (void *) pCurBL);
+						}
+						else
+						{
+							if(vBlock.findItem(pCurBL) < 0)
+							{
+								vBlock.addItem((void *) pCurBL);
+							}
+						}
+					}
+					pLine = pLine->getNext();
+				}
+//
+// Now collapse the blocks that generated these lines.
+//
+				for(UT_uint32 j = 0; j< vBlock.getItemCount(); j++)
+				{
+					pCurBL = (fl_BlockLayout *) vBlock.getNthItem(j);
+					if(!pCurBL->isCollapsed())
+					{
+						pCurBL->collapse();
+					}
+				}
+				pLeader = pLeader->getFollower();
+			}
 
-		//UT_ASSERT(UT_TODO);
-		UT_DEBUGMSG((" fp_Page::_reformat i < count, i= %d count= %d \n",i,count)); 
-		i++;
+			if(pSL != pCurSL)
+			{
+				pCurSL = pSL;
+				pCurSL->markForReformat();
+			}
+			UT_DEBUGMSG((" fp_Page::_reformat i < count, i= %d count= %d \n",i,count)); 
+			i++;
+		}
+
+//
+// Remove these from our vector of leaders and delete the containers.
+//
+  		while(m_vecColumnLeaders.getItemCount() > numValidLeaders)
+  		{
+  			fp_Column* pLeader = getNthColumnLeader(numValidLeaders);
+
+  			// Delete leader from list
+  			m_vecColumnLeaders.deleteNthItem(numValidLeaders);
+  			fp_Column * pFollower = pLeader;
+  			while(pLeader)
+  			{
+  				pFollower = pLeader->getFollower();
+//  				delete pLeader;
+				pLeader->setPage(NULL);
+ 				pLeader = pFollower;
+  			}
+  		}
+//  
+// Now reformat
+//
+		pCurSL = m_pOwner->getNextDocSection();
+		while(pCurSL != NULL)
+		{
+			if(pCurSL->needsReFormat())
+			{
+				pCurSL->format();
+			}
+			pCurSL = pCurSL->getNextDocSection();
+		}
 	}
+
 }
 
 /*!
@@ -402,12 +492,32 @@ void fp_Page::removeColumnLeader(fp_Column* pLeader)
 	// Are there still any rows on this page?
 	int count = countColumnLeaders();
 	if (0 == count)
+	{
 		return;
-
+	}
 	// Update owner and reformat
 	fp_Column* pFirstColumnLeader = getNthColumnLeader(0);
-	m_pOwner = pFirstColumnLeader->getDocSectionLayout();
-
+//
+// Handle change of Page ownership. This can happen when the the previous 
+// Section expands it's text onto a page owned by the next docsection.
+//
+// An alternative is to destroy and recreate the page but this will be much nicer
+// if it can be made to work.
+//
+	if(pFirstColumnLeader->getDocSectionLayout() != m_pOwner)
+	{
+//
+// Change ownership of the page. First remove this page from the set owned by
+// the old docSectionLayout.
+//
+		m_pOwner->deleteOwnedPage(this);
+		fl_DocSectionLayout * pDSLNew = pFirstColumnLeader->getDocSectionLayout();
+//
+// Now add it to the new DSL.
+//
+		pDSLNew->addOwnedPage(this);
+		m_pOwner = pDSLNew;
+	}
 	_reformat();
 }
 
@@ -425,19 +535,37 @@ bool fp_Page::insertColumnLeader(fp_Column* pLeader, fp_Column* pAfter)
 	{
 		UT_sint32 ndx = m_vecColumnLeaders.findItem(pAfter);
 		UT_ASSERT(ndx >= 0);
-
 		m_vecColumnLeaders.insertItemAt(pLeader, ndx+1);
 	}
 	else
 	{
 		m_vecColumnLeaders.insertItemAt(pLeader, 0);
-		// Another urgh! This causes header/footer assertions to
-		// trigger when loading Dom's backend document. Uncomment
-		// until I grok all the implications.
-#if 0
-		m_pOwner = pLeader->getDocSectionLayout();
-		m_pOwner->addOwnedPage(this);
-#endif
+
+		// Update owner and reformat
+
+//
+// Handle change of Page ownership. This can happen when the the previous 
+// Section expands it's text onto a page owned by the next docsection.
+//
+// An alternative is to destroy and recreate the page but this will be much nicer
+// if it can be made to work.
+//
+		if(pLeader->getDocSectionLayout() != m_pOwner)
+		{
+//
+// Change ownership of the page. First remove this page from the set owned by
+// the old docSectionLayout.
+//
+			UT_DEBUGMSG(("SEVIOR: Deleting owned Page from Page \n"));
+			if(m_pOwner)
+				m_pOwner->deleteOwnedPage(this);
+			fl_DocSectionLayout * pDSLNew = pLeader->getDocSectionLayout();
+//
+// Now add it to the new DSL.
+//
+			pDSLNew->addOwnedPage(this);
+			m_pOwner = pDSLNew;
+		}
 	}
 
 	fp_Column* pTmpCol = pLeader;
@@ -716,6 +844,7 @@ const fp_PageSize&	fp_Page::getPageSize(void) const
 
 void fp_Page::removeHeader(void)
 {
+	UT_DEBUGMSG(("SEVIOR: Deleting header from page m_pHeader = %x \n",m_pHeader));
 	if(m_pHeader == NULL)
 		return;
 	delete m_pHeader;
@@ -725,6 +854,7 @@ void fp_Page::removeHeader(void)
 
 void fp_Page::removeFooter(void)
 {
+	UT_DEBUGMSG(("SEVIOR: Deleting header from page m_pFooter = %x \n",m_pFooter));
 	if(m_pFooter == NULL)
 		return;
 	delete m_pFooter;
