@@ -253,6 +253,11 @@ UT_RGBColor * fp_Run::getHighlightColor(void)
 			pPage = pLine->getContainer()->getPage();
 		if(pPage != NULL)
 			pClr = pPage->getOwningSection()->getPaperColor();
+		else if(m_pBL->isHdrFtr())
+		{
+			UT_setColor (m_colorHL, 255, 255, 255);
+			return &m_colorHL;
+		}
 		else
 			pClr = m_pBL->getDocSectionLayout()->getPaperColor();
 		UT_setColor (m_colorHL, pClr->m_red, pClr->m_grn, pClr->m_blu);
@@ -275,6 +280,11 @@ UT_RGBColor * fp_Run::getPageColor(void)
 		pPage = pLine->getContainer()->getPage();
 	if(pPage != NULL)
 		pClr = pPage->getOwningSection()->getPaperColor();
+	else if(m_pBL->isHdrFtr())
+	{
+		UT_setColor (m_colorPG, 0, 0, 0);
+		return &m_colorPG;
+	}
 	else
 		pClr = m_pBL->getDocSectionLayout()->getPaperColor();
 	UT_setColor (m_colorPG, pClr->m_red, pClr->m_grn, pClr->m_blu);
@@ -363,7 +373,8 @@ void fp_Run::setLine(fp_Line* pLine)
 	clearScreen();
 	
 	m_pLine = pLine;
-	updateBackgroundColor();
+	if(pLine != NULL)
+		updateBackgroundColor();
 }
 
 
@@ -1810,11 +1821,18 @@ void fp_ImageRun::_draw(dg_DrawArgs* pDA)
 	pClipRect.left = xoff;
 	pClipRect.height = m_pLine->getContainer()->getHeight();
 	pClipRect.width = m_pLine->getContainer()->getWidth();
-	m_pG->setClipRect(&pClipRect);
-
+	//
+	// SEVIOR Says don't touch this if statement unless you know how to make windows 
+	// and gnome-print print images. Otherwise your commit priviliges will be revoked.
+	//
+	if(m_pG->queryProperties(GR_Graphics::DGP_SCREEN))
+	{
+	    m_pG->setClipRect(&pClipRect);
+	}
 	if (m_pImage)
 	{
 		// draw the image (always)
+		UT_DEBUGMSG(("SEVIOR: Drawing image now \n"));
 		m_pG->drawImage(m_pImage, xoff, yoff);
 
 		// if we're the selection, draw a pretty box
