@@ -306,6 +306,10 @@ public:
 	void                cmdEditHeader(void);
 	void                cmdEditFooter(void);
 
+	void                cmdRemoveHdrFtr(bool isHeader);
+	bool                isFooterOnPage(void);
+	bool                isHeaderOnPage(void);
+
 // ----------------------
 // Stuff for edittable endnotes
 //
@@ -378,6 +382,8 @@ public:
 	inline PD_Document * getDocument (void) const {return m_pDoc;}
 
 protected:
+	void                _saveAndNotifyPieceTableChange(void);
+	void                _restorePieceTableState(void);
 	void				_generalUpdate(void);
 	
 	void 				_draw(UT_sint32, UT_sint32, UT_sint32, UT_sint32, bool bDirtyRunsOnly, bool bClip=false);
@@ -449,7 +455,11 @@ protected:
 
 	void				_checkPendingWordForSpell(void);
 
-        bool                            _isSpaceBefore(PT_DocPosition pos);
+    bool                _isSpaceBefore(PT_DocPosition pos);
+	void                _setScreenUpdateOnGeneralUpdate( bool bDoit) 
+		{m_bDontUpdateScreenOnGeneralUpdate = !bDoit;}
+	bool                _shouldScreenUpdateOnGeneralUpdate(void) const 
+		{ return !m_bDontUpdateScreenOnGeneralUpdate;}
 
 	PT_DocPosition		m_iInsPoint;
 	UT_sint32			m_xPoint;
@@ -524,9 +534,11 @@ protected:
 	// prefs listener - to change cursor blink on/off (and possibly others)
 	static void _prefsListener( XAP_App *, XAP_Prefs *, UT_StringPtrMap *, void *);
 
-	bool		m_bShowPara;
-	ViewMode        m_viewMode;
-	PreViewMode m_previewMode;
+	bool		         m_bShowPara;
+	ViewMode             m_viewMode;
+	PreViewMode          m_previewMode;
+	bool                 m_bDontUpdateScreenOnGeneralUpdate; 
+	bool                 m_bPieceTableState;
 };
 
 #endif /* FV_VIEW_H */
