@@ -52,6 +52,7 @@
 #include "xap_App.h"
 #include "ut_units.h"
 #include "ut_string_class.h"
+#include "ut_sleep.h"
 
 //////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////
@@ -78,7 +79,9 @@ PD_Document::PD_Document(XAP_App *pApp)
 	m_lastSavedAsType(IE_Exp::fileTypeForSuffix(".abw")),
 	m_bPieceTableChanging(false),
 	m_bDoingPaste(false),
-	m_bAllowInsertPointChange(true)
+	m_bAllowInsertPointChange(true),
+	m_bRedrawHappenning(false),
+	m_bLoading(false)
 {
 	m_pApp = pApp;
 
@@ -132,7 +135,7 @@ UT_Error PD_Document::importFile(const char * szFilename, int ieft,
 		UT_DEBUGMSG(("PD_Document::importFile -- could not construct importer\n"));
 		return errorCode;
 	}
-
+	m_bLoading = true;
 	m_pPieceTable->setPieceTableState(PTS_Loading);
 	errorCode = pie->importFile(szFilename);
 	delete pie;
@@ -144,6 +147,7 @@ UT_Error PD_Document::importFile(const char * szFilename, int ieft,
 	}
 	
 	m_pPieceTable->setPieceTableState(PTS_Editing);
+	m_bLoading = false;
 	updateFields();
 
 	if(markClean)	
@@ -516,7 +520,7 @@ bool PD_Document::removeStyle(const XML_Char * pszName)
 //
 // All this code is used to find if this strux has our style in it
 //
-		PT_AttrPropIndex indexAP;
+		PT_AttrPropIndex indexAP = 0;
 		if(currentFrag->getType()  == pf_Frag::PFT_Strux)
 		{
 			pfs = static_cast<pf_Frag_Strux *>(currentFrag);
@@ -1724,7 +1728,13 @@ bool PD_Document::updateFields(void)
 
 void PD_Document::setDontChangeInsPoint(void)
 {
-        m_bAllowInsertPointChange = false;
+	if(m_bLoading)
+	{
+		UT_DEBUGMSG(("Illegal request to not change insertion Point!!! \n"));
+        m_bAllowInsertPointChange = true;
+		return;
+	}
+	m_bAllowInsertPointChange = false;
 }
 
 void PD_Document::allowChangeInsPoint(void)
@@ -1742,7 +1752,19 @@ bool PD_Document::getAllowChangeInsPoint(void) const
 
 void PD_Document::notifyPieceTableChangeStart(void)
 {
-        m_bPieceTableChanging = true;
+//
+// Wait for all redraws to finish before starting.
+//
+	UT_uint32 i = 0;
+	while(m_bRedrawHappenning && i < 10000)
+	{
+		UT_usleep(100); // wait 100 microseonds
+		i++;
+	}
+	if(i>0)
+		UT_DEBUGMSG(("!!!!Waited %d microseconds for redraw to finish \n",i*100));
+	m_bRedrawHappenning = false;
+	m_bPieceTableChanging = true;
 }
 
 
