@@ -428,19 +428,19 @@ bool pt_PieceTable::_tweakDeleteSpan(PT_DocPosition & dpos1,
 	//  We want to keep tweaking the delete span until there is nothing
 	//  more to tweak.  We check to see if nothing has changed in the
 	//  last tweak, and if so, we are done. 
-//	while (1)
-//	{
-//		PT_DocPosition old_dpos1 = dpos1;
-//		PT_DocPosition old_dpos2 = dpos2;
-//		UT_uint32 old_iStackSize = pstDelayStruxDelete->getDepth();
+	while (1)
+	{
+		PT_DocPosition old_dpos1 = dpos1;
+		PT_DocPosition old_dpos2 = dpos2;
+		UT_uint32 old_iStackSize = pstDelayStruxDelete->getDepth();
+		
+		if(!_tweakDeleteSpanOnce(dpos1, dpos2, pstDelayStruxDelete))
+			return false;
 
-	if(!_tweakDeleteSpanOnce(dpos1, dpos2, pstDelayStruxDelete))
-		return false;
-
-//		if (dpos1 == old_dpos1 && dpos2 == old_dpos2
-//			&& pstDelayStruxDelete->getDepth() == old_iStackSize)
-	return true;
-//	}
+		if (dpos1 == old_dpos1 && dpos2 == old_dpos2
+			&& pstDelayStruxDelete->getDepth() == old_iStackSize)
+			return true;
+	}
 }
 
 bool pt_PieceTable::_deleteFormatting(PT_DocPosition dpos1,
@@ -482,6 +482,18 @@ bool pt_PieceTable::_deleteFormatting(PT_DocPosition dpos1,
 			pfTemp = pfNewTemp;
 			fragOffsetTemp = fragOffsetNewTemp;
 		}
+		else if(pfTemp->getType() == pf_Frag::PFT_Strux)
+		{
+			pf_Frag_Strux * pfFragStrux = static_cast<pf_Frag_Strux *>(pfTemp);
+			if(pfFragStrux->getStruxType() == PTX_Section)
+			{
+				pf_Frag_Strux_Section * pfSec = static_cast<pf_Frag_Strux_Section *>(pfFragStrux);
+				_deleteHdrFtrsFromSectionStruxIfPresent(pfSec);
+			}
+			dposTemp += pfTemp->getLength() - fragOffsetTemp;
+			pfTemp = pfTemp->getNext();
+			fragOffsetTemp = 0;
+		}
 		else
 		{
 			dposTemp += pfTemp->getLength() - fragOffsetTemp;
@@ -682,9 +694,11 @@ bool pt_PieceTable::_deleteComplexSpan_norec(PT_DocPosition dpos1,
 	return true;
 }
 
+
+
 bool pt_PieceTable::deleteSpan(PT_DocPosition dpos1,
 							   PT_DocPosition dpos2,
-							   PP_AttrProp *p_AttrProp_Before)
+							   PP_AttrProp *p_AttrProp_Before, bool bDontGlob)
 {
 	// remove (dpos2-dpos1) characters from the document at the given position.
 
@@ -739,7 +753,8 @@ bool pt_PieceTable::deleteSpan(PT_DocPosition dpos1,
 		//  be a bit more careful about deleting the formatting 
 		//  first, and then the actual spans.  Also, glob all
 		//  changes together.
-		beginMultiStepGlob();
+		if(!bDontGlob)
+			beginMultiStepGlob();
 		_changePointWithNotify(old_dpos2);
 
 		bSuccess = _deleteFormatting(dpos1, dpos2);
@@ -780,15 +795,16 @@ bool pt_PieceTable::deleteSpan(PT_DocPosition dpos1,
 		xxx_UT_DEBUGMSG(("pt_PieceTable::deleteSpan Paragraph empty\n"));
 
 		// All text in paragraph is deleted so insert a text format.
-
-		_insertFmtMarkFragWithNotify(PTC_AddFmt, dpos1, &AttrProp_Before);
+		// Except if we're realy don't want it. We know we dont if bDontGlob is true.
+		if(!bDontGlob)
+			_insertFmtMarkFragWithNotify(PTC_AddFmt, dpos1, &AttrProp_Before);
 
 	}
 
 	// By ending the glob after having inserted the FmtMark, an undo
 	// behaves properly, instead of being a two-step operation. See
 	// bug 1140.
-	if (!bIsSimple)
+	if (!bIsSimple && !bDontGlob)
 	{
 		endMultiStepGlob();
 	}
@@ -881,3 +897,8 @@ void pt_PieceTable::_tweakFieldSpan(PT_DocPosition & dpos1,
         dpos2 = getFragPosition(pf_Other);
     }
 }
+
+
+
+
+
