@@ -210,8 +210,8 @@ ap_bs_NVK NVKTable[] =
 						  "",					"",					"",				""					}},
 //	{EV_NVK_HELP,		{ "",					"",					"",				"",
 //						  "",					"",					"",				""					}},
-//	{EV_NVK_F1,			{ "",					"",					"",				"",
-//						  "",					"",					"",				""					}},
+	{EV_NVK_F1,			{ "helpContents",					"",					"",				"",
+						  "",					"",					"",				""					}},
 //	{EV_NVK_F2,			{ "",					"",					"",				"",
 //						  "",					"",					"",				""					}},
 	{EV_NVK_F3,			{ "findAgain",			"",					"",				"",
@@ -230,8 +230,8 @@ ap_bs_NVK NVKTable[] =
 //						  "",					"",					"",				""					}},
 	{EV_NVK_F10,		{ "",					"contextMenu",		"",				"",
 						  "",					"",					"",				""					}},
-//	{EV_NVK_F11,		{ "",					"",					"",				"",
-//						  "",					"",					"",				""					}},
+	{EV_NVK_F11,		{ "viewFullScreen",					"",					"",				"",
+						  "",					"",					"",				""					}},
 	{EV_NVK_F12,		{ "cycleInputMode",		"",					FN_TEST_FTR,				"",
 						  FN_TEST_DUMP,			        "",					"",				""					}},
 // 	{EV_NVK_F13,		{
@@ -361,9 +361,9 @@ ap_bs_Char CharTable[] =
 	{0x59, /* Y      */ { "insertData",			"redo",				"",				""					}},
 	{0x5a, /* Z      */ { "insertData",			"undo",				"",				""					}},
 	{0x5b, /* [      */ { "insertData",			"editHeader",					"",				""					}},
-	{0x5c, /* \      */ { "insertData",			"",					"",				""					}},
+	{0x5c, /* \      */ { "insertData",			"removeHeader",					"",				""					}},
 	{0x5d, /* ]      */ { "insertData",			"editFooter",					"",				""					}},
-	{0x5e, /* ^      */ { "insertData",			"",					"",				""					}},
+	{0x5e, /* ^      */ { "insertData",			"removeFooter",					"",				""					}},
 	{0x5f, /* -      */ { "insertData",			"",					"",				""					}},
 	{0x60, /* `      */ { "insertData",			"",					"",				""					}},
 	{0x61, /* a      */ { "insertData",			"selectAll",		"",				""					}},
