@@ -68,7 +68,7 @@ EV_Menu_ActionSet * AP_CreateMenuActionSet(void)
 	_s(AP_MENU_ID__BOGUS1__,		0,0,0,	NULL,				NULL,					NULL);
 
 	_s(AP_MENU_ID_FILE,				1,0,0,	NULL,				NULL,					NULL);
-	_s(AP_MENU_ID_FILE_NEW,			0,0,0,	"fileNew",			NULL,					NULL);
+	_s(AP_MENU_ID_FILE_NEW,			0,1,0,	"fileNew",			NULL,					NULL);
 	_s(AP_MENU_ID_FILE_OPEN,		0,1,0,	"fileOpen",			NULL,					NULL);
 	_s(AP_MENU_ID_FILE_SAVE,		0,0,0,	"fileSave",			NULL,					NULL);
 	_s(AP_MENU_ID_FILE_SAVEAS,		0,1,0,	"fileSaveAs",		NULL,					NULL);
@@ -105,8 +105,10 @@ EV_Menu_ActionSet * AP_CreateMenuActionSet(void)
 	_s(AP_MENU_ID_EDIT_FIND,		0,1,0,	"find",				NULL,					NULL);
 	_s(AP_MENU_ID_EDIT_REPLACE,		0,1,0,	"replace",			NULL,					NULL);
 	_s(AP_MENU_ID_EDIT_GOTO,		0,1,0,	"go",				NULL,					NULL);
-	_s(AP_MENU_ID_EDIT_EDITHEADER,		0,1,0,	"editHeader",				NULL,					NULL);
-	_s(AP_MENU_ID_EDIT_EDITFOOTER,		0,1,0,	"editFooter",				NULL,					NULL);
+	_s(AP_MENU_ID_EDIT_EDITHEADER,		0,0,0,	"editHeader",	NULL,					NULL);
+	_s(AP_MENU_ID_EDIT_EDITFOOTER,		0,0,0,	"editFooter",	NULL,					NULL);
+	_s(AP_MENU_ID_EDIT_REMOVEHEADER,		0,0,0,"removeHeader",ap_GetState_Changes	,					NULL);
+	_s(AP_MENU_ID_EDIT_REMOVEFOOTER,		0,0,0,	"removeFooter",ap_GetState_Changes,					NULL);
 
 	_s(AP_MENU_ID_VIEW,				1,0,0,	NULL,				NULL,					NULL);
 	_s(AP_MENU_ID_VIEW_NORMAL, 0,0,1, "viewNormalLayout", ap_GetState_View, NULL);
@@ -121,7 +123,14 @@ EV_Menu_ActionSet * AP_CreateMenuActionSet(void)
 	_s(AP_MENU_ID_VIEW_SHOWPARA,	0,0,1,	"viewPara",			ap_GetState_View,		NULL);
 //	_s(AP_MENU_ID_VIEW_HEADFOOT,	0,0,1,	"viewHeadFoot",		ap_GetState_View,		NULL);
 	_s(AP_MENU_ID_VIEW_FULLSCREEN, 0,0,1, "viewFullScreen", ap_GetState_View, NULL);
+	_s(AP_MENU_ID_VIEW_ZOOM_MENU, 1,0,0, NULL, NULL, NULL);
 	_s(AP_MENU_ID_VIEW_ZOOM,		0,1,0,	"dlgZoom",			NULL,					NULL);
+	_s(AP_MENU_ID_VIEW_ZOOM_200, 0,0,0, "zoom200", NULL, NULL);
+	_s(AP_MENU_ID_VIEW_ZOOM_100, 0,0,0, "zoom100", NULL, NULL);
+	_s(AP_MENU_ID_VIEW_ZOOM_75, 0,0,0, "zoom75", NULL, NULL);
+	_s(AP_MENU_ID_VIEW_ZOOM_50, 0,0,0, "zoom50", NULL, NULL);
+	_s(AP_MENU_ID_VIEW_ZOOM_WHOLE, 0,0,0, "zoomWhole", NULL, NULL);
+	_s(AP_MENU_ID_VIEW_ZOOM_WIDTH, 0,0,0, "zoomWidth", NULL, NULL);
 
 	_s(AP_MENU_ID_INSERT,			1,0,0,	NULL,				NULL,					NULL);
 	_s(AP_MENU_ID_INSERT_BREAK,		0,1,0,	"insBreak",			NULL,					NULL);
@@ -167,6 +176,7 @@ EV_Menu_ActionSet * AP_CreateMenuActionSet(void)
 	_s(AP_MENU_ID_TOOLS,			1,0,0,	NULL,				NULL,					NULL);
 	_s(AP_MENU_ID_TOOLS_SPELLING,	        1,0,0,	NULL,				NULL,					NULL);
 	_s(AP_MENU_ID_TOOLS_SPELL,	        0,1,0,	"dlgSpell",		NULL,					NULL);
+	_s(AP_MENU_ID_TOOLS_SPELLPREFS, 0,1,0, "dlgSpellPrefs", NULL, NULL);
 	_s(AP_MENU_ID_TOOLS_AUTOSPELL,          0,0,1,  "toggleAutoSpell",      ap_GetState_Prefs, NULL);
 	_s(AP_MENU_ID_TOOLS_LANGUAGE, 1,0,0, NULL, NULL, NULL);
 	_s(AP_MENU_ID_TOOLS_WORDCOUNT,		0,1,0,	"dlgWordCount",			NULL,					NULL);
@@ -200,6 +210,9 @@ EV_Menu_ActionSet * AP_CreateMenuActionSet(void)
 	_s(AP_MENU_ID_HELP_SEARCH,		0,0,0,	"helpSearch",			NULL,					ap_GetLabel_Search);
 	_s(AP_MENU_ID_HELP_ABOUT,		0,1,0,	"dlgAbout",			NULL,					ap_GetLabel_About);
 	_s(AP_MENU_ID_HELP_ABOUTOS,		0,0,0,	"helpAboutOS",			NULL,					ap_GetLabel_AboutOS);
+	_s(AP_MENU_ID_HELP_ABOUT_GNU, 0,0,0, "helpAboutGnu", NULL, NULL);
+	_s(AP_MENU_ID_HELP_ABOUT_GNOMEOFFICE, 0,0,0, "helpAboutGnomeOffice", NULL, NULL);
+	_s(AP_MENU_ID_HELP_CREDITS, 0,0,0, "helpCredits", NULL, NULL);
 
 	_s(AP_MENU_ID_SPELL_SUGGEST_1,	0,0,0,	"spellSuggest_1",	ap_GetState_Suggest,	ap_GetLabel_Suggest);
 	_s(AP_MENU_ID_SPELL_SUGGEST_2,	0,0,0,	"spellSuggest_2",	ap_GetState_Suggest,	ap_GetLabel_Suggest);
