@@ -197,8 +197,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_About)
 
 	sprintf(buf,szFormat,szAppName);	
 	return buf;
-
-	return NULL;
 }
 
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Contents)
@@ -219,8 +217,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Contents)
 
 	sprintf(buf,szFormat,szAppName);	
 	return buf;
-
-	return NULL;
 }
 
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Index)
@@ -241,8 +237,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Index)
 
 	sprintf(buf,szFormat,szAppName);	
 	return buf;
-
-	return NULL;
 }
 
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Search)
@@ -263,8 +257,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Search)
 
 	sprintf(buf,szFormat,szAppName);	
 	return buf;
-
-	return NULL;
 }
 
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_AboutOS)
@@ -285,8 +277,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_AboutOS)
 
 	sprintf(buf,szFormat,szAppName);	
 	return buf;
-
-	return NULL;
 }
 
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Checkver)
@@ -307,8 +297,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Checkver)
 
 	sprintf(buf,szFormat,szAppName);	
 	return buf;
-
-	return NULL;
 }
 /*****************************************************************/
 /*****************************************************************/
@@ -504,6 +492,16 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_Changes)
 			s = EV_MIS_Gray;
 		break;
 
+	case AP_MENU_ID_EDIT_REMOVEHEADER:
+		if (!pView->isHeaderOnPage())
+			s = EV_MIS_Gray;
+		break;
+
+	case AP_MENU_ID_EDIT_REMOVEFOOTER:
+		if (!pView->isFooterOnPage())
+			s = EV_MIS_Gray;
+		break;
+
 	default:
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		break;
