@@ -78,7 +78,9 @@ BeginSetEnc(it,IT,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_EDIT_REPLACE,		"Sostit&uisci",		"Sostituisce il testo specificato con un altro")
 	MenuLabel(AP_MENU_ID_EDIT_GOTO,			"&Vai a",			"Sposta il cursore nel punto specificato")
 	MenuLabel(AP_MENU_ID_EDIT_EDITHEADER,		"Modifica intestazione",	"Modifica l'intestazione della pagina corrente")
-	MenuLabel(AP_MENU_ID_EDIT_EDITFOOTER,		"Modifica pi di pagina",	"Modifica pi di pagina")
+	MenuLabel(AP_MENU_ID_EDIT_EDITFOOTER,		"Modifica pie' di pagina",	"Modifica pie' di pagina")
+	MenuLabel(AP_MENU_ID_EDIT_REMOVEHEADER,		"Elimina intestazione",		"Toglie l'intestazione da questa pagina del documento")
+	MenuLabel(AP_MENU_ID_EDIT_REMOVEFOOTER,		"Elimina pie' di pagina",	"Toglie il pie' di pagina da questa pagina del documento")
 	
 	MenuLabel(AP_MENU_ID_VIEW,				"&Visualizza",			NULL)
 	MenuLabel(AP_MENU_ID_VIEW_NORMAL, "&Normale", "Vista normale")
@@ -93,7 +95,14 @@ BeginSetEnc(it,IT,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_VIEW_SHOWPARA,		"Visualizza Para&grafi",	"Visualizza i caratteri che non vengono stampati")
 	MenuLabel(AP_MENU_ID_VIEW_HEADFOOT,		"&Intestazione e pi di pagina",	"Edita il testo nell'intestazione e nel pi di ogni pagina")
         MenuLabel(AP_MENU_ID_VIEW_FULLSCREEN, "Schermo &intero", "Mostra il documento a pieno schermo")
+	MenuLabel(AP_MENU_ID_VIEW_ZOOM_MENU, 		"&Zoom", "Riduzione o ingrandimento della visualizzazione di un documento")
 	MenuLabel(AP_MENU_ID_VIEW_ZOOM,			"&Zoom",				"Riduce o ingrandisce il documento visualizzato")
+        MenuLabel(AP_MENU_ID_VIEW_ZOOM_200, 		"Zoom al &200%", "Zoom al 200%")
+        MenuLabel(AP_MENU_ID_VIEW_ZOOM_100, 		"Zoom al &100%", "Zoom al 100%")
+        MenuLabel(AP_MENU_ID_VIEW_ZOOM_75, 		"Zoom al &75%", "Zoom al 75%")
+        MenuLabel(AP_MENU_ID_VIEW_ZOOM_50, 		"Zoom al &50%", "Zoom al 50%")
+        MenuLabel(AP_MENU_ID_VIEW_ZOOM_WIDTH, 		"Zoom a &pagina intera ", "Zoom a pagina intera")
+        MenuLabel(AP_MENU_ID_VIEW_ZOOM_WHOLE, 		"Zoom alla larghezza della &pagina", "Zoom alla larghezza della pagina")
 
 	MenuLabel(AP_MENU_ID_INSERT,			"&Inserisci",			NULL)
 	MenuLabel(AP_MENU_ID_INSERT_BREAK,		"&Interruzione",		"Inserisce un'interruzione di pagina , colonna o sessione")
@@ -101,6 +110,7 @@ BeginSetEnc(it,IT,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_INSERT_DATETIME,	"Da&ta e ora",			"Inserisce la data e/o l'ora")
 	MenuLabel(AP_MENU_ID_INSERT_FIELD,		"&Campo",				"Inserisce un campo di calcolo")
 	MenuLabel(AP_MENU_ID_INSERT_SYMBOL,		"&Simbolo",				"Inserisce un simobolo o un altro carattere speciale")
+	MenuLabel(AP_MENU_ID_INSERT_ENDNOTE,		"&Nota di chiusura",			"Inserisci una nota di chiusura")
         MenuLabel(AP_MENU_ID_INSERT_PICTURE, "&Immagine", "Inserisci una immagine")
 	MenuLabel(AP_MENU_ID_INSERT_CLIPART, "&Clip Art", "Inserisci una clipart")
 	MenuLabel(AP_MENU_ID_INSERT_GRAPHIC,	"&Da File",				"Inserisce un'immagine esistente, da un altro file")
@@ -131,6 +141,7 @@ BeginSetEnc(it,IT,true,"iso-8859-1")
         MenuLabel(AP_MENU_ID_TOOLS_SPELLING, "&Controllo ortografico", NULL)
 	MenuLabel(AP_MENU_ID_TOOLS_SPELL,		"&Controllo ortografico",	"Controlla l'ortografia del documento")
         MenuLabel(AP_MENU_ID_TOOLS_AUTOSPELL, "Controllo ortografico &automatico", "Controlla automaticamente l'ortografia del documento")
+        MenuLabel(AP_MENU_ID_TOOLS_SPELLPREFS, 		"&Opzioni controllo ortografico", "Setta le tue preferenze per il controllo ortografico")
  	MenuLabel(AP_MENU_ID_TOOLS_WORDCOUNT,	"&Conteggio parole",			"Conta il numero delle parole nel documento")
 	MenuLabel(AP_MENU_ID_TOOLS_OPTIONS,		"&Opzioni",					"Setta le opzioni")
         MenuLabel(AP_MENU_ID_TOOLS_LANGUAGE,		"Li&ngua",			"Cambia la linuga del testo selezionato")
@@ -161,12 +172,15 @@ BeginSetEnc(it,IT,true,"iso-8859-1")
 	MenuLabel(AP_MENU_ID_WINDOW_MORE,		"&Dispondi tutto",		"Visualizza tutta la lista delle finestre")
 
 	MenuLabel(AP_MENU_ID_HELP,				"&Aiuto",					NULL)
+	MenuLabel(AP_MENU_ID_HELP_CREDITS, 		"C&rediti", 		"Mostra i crediti")
 	MenuLabel(AP_MENU_ID_HELP_CONTENTS,		"&Contenuto dell'Aiuto",	"Mostra il contenuto dell'Aiuto")
 	MenuLabel(AP_MENU_ID_HELP_INDEX,		"&Indice",		"Mostra l'indice")
 	MenuLabel(AP_MENU_ID_HELP_CHECKVER,		"Mostra la &Versione",	"Mostra il numero di versione del programma")
 	MenuLabel(AP_MENU_ID_HELP_SEARCH,		"&Ricerca Aiuto",	"Mostra le informazioni sul programma, il numero di versione ed il copyright")
 	MenuLabel(AP_MENU_ID_HELP_ABOUT,		"In&formazioni su %s",	"Mostra le informazioni sul programma, il numero di versione ed il copyright")
 	MenuLabel(AP_MENU_ID_HELP_ABOUTOS,		"Sull'&Open Source",	"Mostra informazioni sull'Open Source")
+	MenuLabel(AP_MENU_ID_HELP_ABOUT_GNU, 		"Sul software libero &GNU", "Informazioni sul progetto GNU")
+	MenuLabel(AP_MENU_ID_HELP_ABOUT_GNOMEOFFICE, 	"Su G&NOME Office", 	"Informazioni sul progetto GNOME Office")
 
         MenuLabel(AP_MENU_ID_SPELL_SUGGEST_1,   "%s",                           "Cambia in questa parola suggerita")                                                
         MenuLabel(AP_MENU_ID_SPELL_SUGGEST_2,   "%s",                           "Cambia in questa parola suggerita")                                                
