@@ -49,75 +49,6 @@
 /*****************************************************************/
 /*****************************************************************/
 
-#ifdef ENABLE_PLUGINS
-
-// completely generic code to allow this to be a plugin
-
-#include "xap_Module.h"
-
-#define SUPPORTS_ABI_VERSION(a,b,c) (((a==0)&&(b==7)&&(c==15)) ? 1 : 0)
-
-// we use a reference-counted sniffer
-static IE_Exp_AbiWord_1_Sniffer * m_sniffer = 0;
-
-ABI_FAR extern "C"
-int abi_plugin_register (XAP_ModuleInfo * mi)
-{
-
-	if (!m_sniffer)
-	{
-		m_sniffer = new IE_Exp_AbiWord_1_Sniffer ();
-	}
-	else
-	{
-		m_sniffer->ref();
-	}
-
-	mi->name = "AbiWord Exporter";
-	mi->desc = "Export AbiWord Documents";
-	mi->version = "0.7.15";
-	mi->author = "Abi the Ant";
-	mi->usage = "No Usage";
-
-	IE_Exp::registerExporter (m_sniffer);
-	return 1;
-}
-
-ABI_FAR extern "C"
-int abi_plugin_unregister (XAP_ModuleInfo * mi)
-{
-	mi->name = 0;
-	mi->desc = 0;
-	mi->version = 0;
-	mi->author = 0;
-	mi->usage = 0;
-
-	UT_ASSERT (m_sniffer);
-
-	IE_Exp::unregisterExporter (m_sniffer);
-	if (!m_sniffer->unref())
-	{
-		m_sniffer = 0;
-	}
-
-	return 1;
-}
-
-ABI_FAR extern "C"
-int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
-								 UT_uint32 release)
-{
-	return SUPPORTS_ABI_VERSION(major, minor, release);
-}
-
-#endif
-
-/*****************************************************************/
-/*****************************************************************/
-
-/*****************************************************************/
-/*****************************************************************/
-
 bool IE_Exp_AbiWord_1_Sniffer::recognizeSuffix(const char * szSuffix)
 {
 	return (!UT_stricmp(szSuffix,".abw"));
@@ -509,72 +440,9 @@ s_AbiWord_1_Listener::s_AbiWord_1_Listener(PD_Document * pDocument,
 	m_pie->write("<!-- =====================================================================  -->\n");
 	m_pie->write("\n");
 
-	m_pie->write("<!--         Build_ID          = ");
-	if (XAP_App::s_szBuild_ID && XAP_App::s_szBuild_ID[0])
-	{
-		m_pie->write(XAP_App::s_szBuild_ID);
-	}
-	else
-	{
-		m_pie->write("(none)");
-	}
-	m_pie->write(" -->\n");
-	m_pie->write("<!--         Build_Version     = ");
-	if (XAP_App::s_szBuild_Version && XAP_App::s_szBuild_Version[0])
-	{
-		m_pie->write(XAP_App::s_szBuild_Version);
-	}
-	else
-	{
-		m_pie->write("(none)");
-	}
-	m_pie->write(" -->\n");
-	m_pie->write("<!--         Build_Options     = ");
-	if (XAP_App::s_szBuild_Options && XAP_App::s_szBuild_Options[0])
-	{
-		m_pie->write(XAP_App::s_szBuild_Options);
-	}
-	else
-	{
-		m_pie->write("(none)");
-	}
-	m_pie->write(" -->\n");
-	m_pie->write("<!--         Build_Target      = ");
-	if (XAP_App::s_szBuild_Target && XAP_App::s_szBuild_Target[0])
-	{
-		m_pie->write(XAP_App::s_szBuild_Target);
-	}
-	else
-	{
-		m_pie->write("(none)");
-	}
-	m_pie->write(" -->\n");
-	m_pie->write("<!--         Build_CompileTime = ");
-	if (XAP_App::s_szBuild_CompileTime && XAP_App::s_szBuild_CompileTime[0])
-	{
-		m_pie->write(XAP_App::s_szBuild_CompileTime);
-	}
-	else
-	{
-		m_pie->write("(none)");
-	}
-	m_pie->write(" -->\n");
-	m_pie->write("<!--         Build_CompileDate = ");
-	if (XAP_App::s_szBuild_CompileDate && XAP_App::s_szBuild_CompileDate[0])
-	{
-		m_pie->write(XAP_App::s_szBuild_CompileDate);
-	}
-	else
-	{
-		m_pie->write("(none)");
-	}
-	m_pie->write(" -->\n");
-	m_pie->write("\n");
-
 	// end of preamble.
 	// now we begin the actual document.
-	
-	
+		
 	_handleStyles();
 	_handleIgnoredWords();
 	_handleLists();
@@ -746,10 +614,10 @@ bool s_AbiWord_1_Listener::signal(UT_uint32 /* iSignal */)
 
 UT_Error IE_Exp_AbiWord_1::_writeDocument(void)
 {
-	m_pListener = new s_AbiWord_1_Listener(m_pDocument,this, m_bIsTemplate);
+	m_pListener = new s_AbiWord_1_Listener(getDoc(),this, m_bIsTemplate);
 	if (!m_pListener)
 		return UT_IE_NOMEMORY;
-	if (!m_pDocument->tellListener(static_cast<PL_Listener *>(m_pListener)))
+	if (!getDoc()->tellListener(static_cast<PL_Listener *>(m_pListener)))
 		return UT_ERROR;
 	delete m_pListener;
 
