@@ -1141,10 +1141,10 @@ bool s_LaTeX_Listener::signal(UT_uint32 /* iSignal */)
 
 UT_Error IE_Exp_LaTeX::_writeDocument(void)
 {
-	m_pListener = new s_LaTeX_Listener(m_pDocument,this);
+	m_pListener = new s_LaTeX_Listener(getDoc(),this);
 	if (!m_pListener)
 		return UT_IE_NOMEMORY;
-	if (!m_pDocument->tellListener(static_cast<PL_Listener *>(m_pListener)))
+	if (!getDoc()->tellListener(static_cast<PL_Listener *>(m_pListener)))
 		return UT_ERROR;
 	delete m_pListener;
 
