@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <locale.h>
 
 #include "wv.h"
 #include "ie_imp_MsWord_97.h"
@@ -42,6 +43,9 @@
 
 #define X_CheckError(v)			do { if (!(v)) return 1; } while (0)
 
+// undef this to disable support for older images (<= Word95)
+#define SUPPORTS_OLD_IMAGES 1
+
 //
 // Just FYI, "dir" and "dom-dir" only get set if BIDI_ENABLED is set.
 // Regardless of BIDI_ENABLED, if CHP::fBidi == 1, the BiDi versions
@@ -355,19 +359,19 @@ IE_Imp_MsWord_97::~IE_Imp_MsWord_97()
 }
 
 IE_Imp_MsWord_97::IE_Imp_MsWord_97(PD_Document * pDocument)
-	: IE_Imp (pDocument), m_iImageCount (0), m_nSections(0)
+	: IE_Imp (pDocument), m_iImageCount (0), m_nSections(0), m_bSetPageSize(false)
 {
 }
 
 /****************************************************************************/
 /****************************************************************************/
 
-#define ErrCleanupAndExit(code)  do {wvOLEFree (); return (code); FREEP(password);} while(0)
+#define ErrCleanupAndExit(code)  do {wvOLEFree (); FREEP(password); return(code);} while(0)
 
 // TODO: DOM: *actually define these*
-#define GetPassword() _getPassword ( m_pDocument->getApp()->getLastFocussedFrame() )
+#define GetPassword() _getPassword ( getDoc()->getApp()->getLastFocussedFrame() )
 
-#define ErrorMessage(x) do { XAP_Frame *_pFrame = m_pDocument->getApp()->getLastFocussedFrame(); _errorMessage (_pFrame, (x)); } while (0)
+#define ErrorMessage(x) do { XAP_Frame *_pFrame = getDoc()->getApp()->getLastFocussedFrame(); _errorMessage (_pFrame, (x)); } while (0)
 
 static char * _getPassword (XAP_Frame * pFrame)
 {
@@ -454,17 +458,11 @@ UT_Error IE_Imp_MsWord_97::importFile(const char * szFilename)
 	return UT_OK;
 }
 
-void IE_Imp_MsWord_97::pasteFromBuffer (PD_DocumentRange *, 
-										unsigned char *, unsigned int, const char *)
-{
-	// nada
-}
-
 void IE_Imp_MsWord_97::_flush ()
 {
 	if (m_pTextRun.size())
 	{
-		if (!m_pDocument->appendSpan(m_pTextRun.ucs_str(), m_pTextRun.size()))
+		if (!getDoc()->appendSpan(m_pTextRun.ucs_str(), m_pTextRun.size()))
 		{
 			UT_DEBUGMSG(("DOM: error appending text run\n"));
 			return;
@@ -777,13 +775,13 @@ int IE_Imp_MsWord_97::_beginSect (wvParseStruct *ps, UT_uint32 tag,
 
 	// page-margin-header
 	sprintf(propBuffer,
-			"parge-margin-header:%s;",
+			"page-margin-header:%s;",
 			UT_convertInchesToDimensionString(DIM_IN, (((float)asep->dyaHdrTop) / 1440), "1.4"));
 	props += propBuffer;
 
 	// page-margin-footer
 	sprintf(propBuffer,
-			"parge-margin-footer:%s;",
+			"page-margin-footer:%s;",
 			UT_convertInchesToDimensionString(DIM_IN, (((float)asep->dyaHdrBottom) / 1440), 
 											  "1.4"));
 	props += propBuffer;
@@ -818,11 +816,15 @@ int IE_Imp_MsWord_97::_beginSect (wvParseStruct *ps, UT_uint32 tag,
 	//
 	// TODO: headers/footers, section breaks
 	//
-
+//
+// Sevior: Only do this ONCE!!! Abiword can only handle one page size.
+//
+	if(!m_bSetPageSize)
 	{
 		//
 		// all of this data is related to Abi's <pagesize> tag
 		//
+		m_bSetPageSize = true;
 		double page_width  = 0.0;
 		double page_height = 0.0;
 		double page_scale  = 1.0;
@@ -831,9 +833,9 @@ int IE_Imp_MsWord_97::_beginSect (wvParseStruct *ps, UT_uint32 tag,
 		const char * paper_name = 0;
 
 		if (asep->dmOrientPage == 1)
-			m_pDocument->m_docPageSize.setLandscape ();
+			getDoc()->m_docPageSize.setLandscape ();
 		else
-			m_pDocument->m_docPageSize.setPortrait ();
+			getDoc()->m_docPageSize.setPortrait ();
 
 		page_width = asep->xaPage / 1440.0;
 		page_height = asep->yaPage / 1440.0;
@@ -845,23 +847,23 @@ int IE_Imp_MsWord_97::_beginSect (wvParseStruct *ps, UT_uint32 tag,
 
 		if (paper_name) {
 			// we found a paper name
-			m_pDocument->m_docPageSize.Set (paper_name);
+			getDoc()->m_docPageSize.Set (paper_name);
 		}
 		else {
 			// this can cause us to SEGV, so I'm not sure if we even want to set it...
 			// TODO: make more mappings for s_MapPageIdToString as I discover them
-			m_pDocument->m_docPageSize.Set (page_width, page_height, fp_PageSize::inch);
+			getDoc()->m_docPageSize.Set (page_width, page_height, fp_PageSize::inch);
 		}
-		m_pDocument->m_docPageSize.setScale(page_scale);
+		getDoc()->m_docPageSize.setScale(page_scale);
 	}
 
-	xxx_UT_DEBUGMSG (("DOM: the section properties are: '%s'\n", props.c_str()));
+	xxx_UT_DEBUGMSG (("DOM:SEVIOR the section properties are: '%s'\n", props.c_str()));
 
 	propsArray[0] = (XML_Char *)"props";
 	propsArray[1] = (XML_Char *)props.c_str();
 	propsArray[2] = 0;
 
-	if (!m_pDocument->appendStrux(PTX_Section, (const XML_Char **)propsArray))
+	if (!getDoc()->appendStrux(PTX_Section, (const XML_Char **)propsArray))
 	{
 		UT_DEBUGMSG (("DOM: error appending section props!\n"));
 		return 1;
@@ -881,10 +883,11 @@ int IE_Imp_MsWord_97::_beginSect (wvParseStruct *ps, UT_uint32 tag,
 	 * 4 Odd page
 	 */
 
-	if (asep->bkc > 1 && m_nSections > 1) // don't apply on the 1st page
+//	if (asep->bkc > 1 && m_nSections > 1) // don't apply on the 1st page
+	if (m_nSections > 1) // don't apply on the 1st page
 	{
-		// new section
-		if (!m_pDocument->appendStrux(PTX_Block, (const XML_Char **)NULL))
+		// new sections always need a block
+		if (!getDoc()->appendStrux(PTX_Block, (const XML_Char **)NULL))
 		{
 			UT_DEBUGMSG (("DOM: error appending new block\n"));
 			return 1;
@@ -894,19 +897,19 @@ int IE_Imp_MsWord_97::_beginSect (wvParseStruct *ps, UT_uint32 tag,
 		switch (asep->bkc) {
 		case 1: 
 			ucs = UCS_VTAB;
-			X_CheckError(m_pDocument->appendSpan(&ucs,1)); 
+			X_CheckError(getDoc()->appendSpan(&ucs,1)); 
 			break;
 			
 		case 2:
-			X_CheckError(m_pDocument->appendSpan(&ucs,1)); 
+			X_CheckError(getDoc()->appendSpan(&ucs,1)); 
 			break;
 			
 		case 3: // TODO: handle me better (not even)
-			X_CheckError(m_pDocument->appendSpan(&ucs,1)); 
+			X_CheckError(getDoc()->appendSpan(&ucs,1)); 
 			break;
 			
 		case 4: // TODO: handle me better (not odd)
-			X_CheckError(m_pDocument->appendSpan(&ucs,1)); 
+			X_CheckError(getDoc()->appendSpan(&ucs,1)); 
 			break;
 			
 		case 0:
@@ -1000,7 +1003,7 @@ int IE_Imp_MsWord_97::_beginPara (wvParseStruct *ps, UT_uint32 tag,
 		// TODO: in the paragraph, instead; but this
 		// TODO: gives a similar effect for now.
 		UT_UCSChar ucs = UCS_FF;
-		m_pDocument->appendSpan(&ucs,1);
+		getDoc()->appendSpan(&ucs,1);
 	}
 
 	// widowed/orphaned lines
@@ -1105,7 +1108,7 @@ int IE_Imp_MsWord_97::_beginPara (wvParseStruct *ps, UT_uint32 tag,
 	propsArray[1] = (XML_Char *)props.c_str();
 	propsArray[2] = 0;
 	
-	if (!m_pDocument->appendStrux(PTX_Block, (const XML_Char **)propsArray))
+	if (!getDoc()->appendStrux(PTX_Block, (const XML_Char **)propsArray))
 	{
 		UT_DEBUGMSG(("DOM: error appending paragraph block\n"));
 		return 1;
@@ -1161,10 +1164,10 @@ int IE_Imp_MsWord_97::_beginChar (wvParseStruct *ps, UT_uint32 tag,
 		codepage = XAP_EncodingManager::get_instance()->getNativeUnicodeEncodingName();
 	// if this is the first codepage we've seen, use it.
 	// if we see more than one different codepage in a document, use unicode.
-	if (!m_pDocument->getEncodingName())
-		m_pDocument->setEncodingName(codepage.c_str());
-	else if (m_pDocument->getEncodingName() != codepage)
-		m_pDocument->setEncodingName(XAP_EncodingManager::get_instance()->getNativeUnicodeEncodingName());
+	if (!getDoc()->getEncodingName())
+		getDoc()->setEncodingName(codepage.c_str());
+	else if (getDoc()->getEncodingName() != codepage)
+		getDoc()->setEncodingName(XAP_EncodingManager::get_instance()->getNativeUnicodeEncodingName());
 	
 #ifdef BIDI_ENABLED
 
@@ -1280,7 +1283,7 @@ int IE_Imp_MsWord_97::_beginChar (wvParseStruct *ps, UT_uint32 tag,
 	propsArray[0] = (XML_Char *)"props";
 	propsArray[1] = (XML_Char *)props.c_str();
 	propsArray[2] = 0;
-	if (!m_pDocument->appendFmt((const XML_Char **)propsArray))
+	if (!getDoc()->appendFmt((const XML_Char **)propsArray))
 	{
 		UT_DEBUGMSG(("DOM: error appending character formatting\n"));
 		return 1;
@@ -1437,7 +1440,7 @@ bool IE_Imp_MsWord_97::_handleCommandField (char *command)
 			continue;
 	    }
 
-		if (!m_pDocument->appendObject (PTO_Field, (const XML_Char**)atts))
+		if (!getDoc()->appendObject (PTO_Field, (const XML_Char**)atts))
 		{
 			UT_DEBUGMSG(("Dom: couldn't append field (type = '%s')\n", atts[1]));
 		}
@@ -1503,10 +1506,13 @@ UT_Error IE_Imp_MsWord_97::_handleImage (Blip * b, long width, long height)
 
 	XML_Char propBuffer[128];
 	propBuffer[0] = 0;
+
+	setlocale(LC_NUMERIC, "C");
 	sprintf(propBuffer, "width:%fin; height:%fin", 
 			(double)width / (double)1440, 
 			(double)height / (double)1440);
-	
+	setlocale(LC_NUMERIC, "");
+
 	XML_Char propsName[32];
 	propsName[0] = 0;
 	sprintf(propsName, "image%d", m_iImageCount++);
@@ -1533,7 +1539,7 @@ UT_Error IE_Imp_MsWord_97::_handleImage (Blip * b, long width, long height)
 		}
 	}
 	
-	if (!m_pDocument->appendObject (PTO_Image, propsArray))
+	if (!getDoc()->appendObject (PTO_Image, propsArray))
 	{
 		UT_DEBUGMSG (("Could not append object\n"));
 		DELETEP(buf);
@@ -1547,7 +1553,7 @@ UT_Error IE_Imp_MsWord_97::_handleImage (Blip * b, long width, long height)
 		return UT_ERROR;
 	}
 
-	if (!m_pDocument->createDataItem((char*)propsName, false,
+	if (!getDoc()->createDataItem((char*)propsName, false,
 									 pBBPNG, (void*)mimetype, NULL))
 	{
 		UT_DEBUGMSG (("Could not create data item\n"));
