@@ -36,6 +36,12 @@
 #include <glib.h>
 #include <string.h>
 
+#ifndef HAVE_GNOMEVFS
+#ifdef HAVE_IO_H
+#include <io.h>			/* use "normal" IO */
+#endif
+#endif
+
 #include "ms-ole.h"
 
 #ifdef HAVE_MMAP
