@@ -29,7 +29,7 @@
  *          Addison-Wesley, 1983. ISBN 0-201-06672-6.
  */
 
-/* @(#) $Id: trees.c,v 1.1.1.1 1999/02/15 20:28:43 eric Exp $ */
+/* @(#) $Id: trees.c,v 1.2 2001/08/09 20:40:31 paul Exp $ */
 
 /* #define GEN_TREES_H */
 
@@ -1107,7 +1107,7 @@ local void compress_block(s, ltree, dtree)
         } /* literal or match pair ? */
 
         /* Check that the overlay between pending_buf and d_buf+l_buf is ok: */
-        Assert(s->pending < s->lit_bufsize + 2*lx, "pendingBuf overflow");
+        Assert(s->pending < (int)(s->lit_bufsize + 2*lx), "pendingBuf overflow");
 
     } while (lx < s->last_lit);
 
